Estimates from Monte Carlo Simulation
Value
a list.
If class of object is "MCS", the list contains the following elements:
medianmedian of the Monte Carlo simulations
ir.95the 95% and 68% interpercentile range
ir.68the 68% interpercentile range
meanarithmetic mean the Monte Carlo simulations
sd1\(\sigma\) standard deviation
conf.int95% confidence intverval about the mean
stderrstandard error
t.testStatistic and p-value of the Student's t-test
nNumber of samples
If class of object is "MCS_log", the list contains the following elements:
medianmedian of the Monte Carlo simulations
ir.95the 95% and 68% interpercentile range
ir.68the 68% interpercentile range
meangeometric mean the Monte Carlo simulations
sd1\(\sigma\) range about the mean
sd22\(\sigma\) range about the mean
conf.int95% confidence intverval about the mean
stderr.logstandard error of
log(samples)t.testStatistic and p-value of the Student's t-test of
log(samples)nNumber of samples
Values will be in the unit specified by parameter unit or be equal to the
unit of x if x is a units object.
Details
Equations of the form \(X = A b^{n \pm \sigma}\) create non-normal, left-skewed distributions (e.g. flow laws, and grain-size piezometers). Thus, it is recommended to report median and percentiles instead of mean, standard deviation and confidence intervals.
Examples
set.seed(20250411)
MC_res <- grainsize_piezometry(12.2)
summary(MC_res)
#> Statistical summary of 1000000 Monte Carlo simulations
#>
#> Median: 92 MPa
#> 95% interpercentile range: 49 - 190 MPa
#> Standard error in log-space: 0.000151644
#> Student's t-Test: p<0.05
n <- 100
temperature <- units::set_units(rnorm(n, 300, 25), degC)
pressure <- units::set_units(rnorm(n, 400, 50), MPa)
MC_res2 <- ps_fugacity(pressure, temperature) # 37 MPa
summary(MC_res2)
#> Statistical summary of 100 Monte Carlo simulations
#>
#> Mean: 390 bar
#> 95% confidence interval: 370 - 420 bar
#> Standard error: 11.9467
#> Student's t-Test: p<0.05